django-jsanctions
=================

Parses and imports sanction lists for Django projects. Supports Django 3.0. Unit test coverage 81%.

Supported sanction lists:
* EU combined sanctions list

Data Sources
============

* http://data.europa.eu/euodp/en/data/dataset/consolidated-list-of-persons-groups-and-entities-subject-to-eu-financial-sanctions

Install
=======

* pip install django-jsanctions

Unit Tests
==========

* ./test-coverage

Changes
=======

3.5.0:
+ Refactoring

3.0.0:
+ Django 3.0 support
